@@ -17,6 +17,11 @@ enum Opcode {
     PYC_INVALID_OPCODE = -1,
 };
 
+enum DisassemblyFlags {
+    DISASM_PYCODE_VERBOSE = 0x1,
+    DISASM_SHOW_CACHES = 0x2,
+};
+
 const char* OpcodeName(int opcode);
 int ByteToOpcode(int maj, int min, int opcode);
 
@@ -32,4 +37,4 @@ bool IsCompareArg(int opcode);
 
 void print_const(PycRef<PycObject> obj, PycModule* mod, const char* parent_f_string_quote = nullptr);
 void bc_next(PycBuffer& source, PycModule* mod, int& opcode, int& operand, int& pos);
-void bc_disasm(PycRef<PycCode> code, PycModule* mod, int indent);
+void bc_disasm(PycRef<PycCode> code, PycModule* mod, int indent, unsigned flags);
