@@ -7,7 +7,46 @@ from typing import List
 from .. import configuration, pyc_checker
 from ..pyc_checker.pyc import PycHandler
 from ..py_package import PackageStruct, PackageDescription
-from PyInstaller.utils.cliutils.archive_viewer import get_archive, get_data, get_content, get_archive_content
+from PyInstaller.utils.cliutils.archive_viewer import ArchiveViewer
+
+import sys
+from PyInstaller.archive.readers import CArchiveReader, ZlibArchiveReader
+from sgtpyutils.logger import logger
+
+
+
+
+def get_archive(filename: str):
+    viewer = ArchiveViewer(filename=filename,
+                           interactive_mode=False,
+                           recursive_mode=False,
+                           brief_mode=True)
+    arch = None
+    arch = viewer._open_toplevel_archive(filename)
+    return arch
+    archive_name = os.path.basename(viewer.filename)
+    viewer.stack.append((archive_name, arch))
+    archive_count = 0
+    toc = {}
+    while viewer.stack:
+        archive_name, archive = viewer.stack.pop()
+        archive_count += 1
+        toc[archive_name] = archive
+        if not viewer.recursive_mode:
+            continue
+
+        # Scan for embedded archives
+        if isinstance(archive, CArchiveReader):
+            for name, (*_, typecode) in archive.toc.items():
+                if typecode == 'z':
+                    try:
+                        embedded_archive = archive.open_embedded_archive(name)
+                    except Exception as e:
+                        logger.warn(
+                            f"Could not open embedded archive {name!r}: {e}")
+                    viewer.stack.append((name, embedded_archive))
+    setattr(viewer, 'toc', toc)
+    return viewer
 
 
 class FileTypeFlag():
@@ -79,7 +118,8 @@ class CommonDump():
 
     def handle_arch_file(self, target_file: str):
         output_dir = self.build_output_dir()
-        arch = get_archive(target_file)
+        arch = get_archive(filename=target_file)
+
         self.extract_arch(arch, output_dir)
         self.file_struct_pyc.progress_check()
         return f'{self.total_handled_count} arch file(s) handled.'
@@ -113,13 +153,13 @@ class CommonDump():
             time.sleep(3)
 
     def statistics_status(self, is_end: bool = False):
+        from sgtpyutils import timer
         if is_end:
-            g = self.global_start_time
-            cost = time.time() - g
-            cost = math.ceil(cost*1e3)
-            logger.info(f'completed,cost {cost}ms with result:{self.result}')
+            t = self.global_start_time
+            logger.info(
+                f'completed,cost {math.ceil(t.spent * 1000)}ms with result:{self.result}')
             return
-        self.global_start_time = time.time()
+        self.global_start_time = timer.create_timer()
 
     def main(self, target_file: str, output_directory: str, thread: int = 0, timeout: int = 10, target_file_type: str = None, session_timeout: int = 120, plugin: List = [], decompile_file: List = None, struct_headers: str = None, **args):
         self.statistics_status()
@@ -140,6 +180,8 @@ class CommonDump():
             logger.error('target_file is required')
             return
         logger.debug(f'target file input:{target_file}\nto:{output_directory}')
+        if not os.path.exists(target_file):
+            logger.error('target_file not exist')
 
         if os.path.exists(output_directory):
             logger.info(f'removing output_directory')
@@ -150,9 +192,13 @@ class CommonDump():
         file_type = target_file_type or self.get_filetype(target_file)
         dispatch_to = self.action_map.get(file_type, None)
 
-        logger.debug(f'start dump target file.')
+        logger.debug(f'start dump target file. type:{dispatch_to}')
         if dispatch_to != FileTypeFlag.FLAG_NOTFILE:
-            os.chdir(os.path.dirname(target_file))
+            abs_path = os.path.abspath(target_file)
+            target_dir = os.path.dirname(abs_path)
+            os.chdir(target_dir)
+            # convert absolute path to relative path
+            target_file = os.path.basename(target_file)
             time.sleep(3)
         self.result = self.action_dispatch[dispatch_to](target_file)
 
@@ -180,12 +226,16 @@ class CommonDump():
         if not os.path.exists(current_directory):
             os.makedirs(current_directory)
         children_package = arch.toc
-        if isinstance(children_package, dict):
-            children_package = list(filter(
-                lambda x: not x.startswith('_'), list(children_package)))
-        else:
-            children_package = children_package.data
-        children_package = list(children_package)
+        # if isinstance(children_package, dict):
+        #     children_package = list(filter(
+        #         lambda x: not x.startswith('_'), list(children_package)))
+        # else:
+        #     children_package = children_package.data
+        # children_package = list(children_package)
+
+        children_package = list(children_package.items())
+        children_package = list(
+            filter(lambda x: not x[0].startswith('_'), children_package))
         self.total_handled_count += len(children_package)
         for package in children_package:
             p = PackageDescription(package, arch, current_directory)
